@@ -1,6 +1,6 @@
 #-*- coding: utf-8 -*-
 
-# Copyright 2008-2012 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -26,7 +26,8 @@ from calculate.lib.utils.common import getSupportArch,getTupleVersion, \
                             cmpVersion
 from calculate.lib.utils.files import readLinesFile, listDirectory
 from calculate.lib.variables.linux import Linux
-from calculate.install.cl_distr import (Distributive,PartitionDistributive,
+from calculate.install.distr import (Distributive,PartitionDistributive,
+    DirectoryDistributive,
     ScratchPartitionDistributive,DistributiveError,FlashDistributive,
     MultiPartitions,PxeDistributive)
 
@@ -291,6 +292,8 @@ class VariableClImageFilename(Variable,DistroRepository):
 
     def check(self,isoimage):
         """Set image file"""
+        if self.Get('cl_action') == 'system' and not isoimage:
+            raise VariableError(_("Need to choice distribute image"))
         imageData = Distributive().getInfo(isoimage)
         if not("os_linux_shortname" in imageData and \
                imageData.get('os_linux_build','') and \
@@ -459,6 +462,15 @@ class VariableClImagePath(ReadonlyVariable):
                ['/var/calculate/remote/linux',
                 '/var/calculate/linux'] + livedistr)
 
+class VariableClSource(ReadonlyVariable):
+    """
+    Дистрибутив текущей системы
+    """
+    type = "object"
+
+    def get(self):
+        return DirectoryDistributive('/')
+
 class VariableClTarget(ReadonlyVariable):
     """
     Target distributive
@@ -539,8 +551,8 @@ class VariableClImageNewOnly(Variable):
     value = "off"
 
     def init(self):
-        self.label = _("Install newer images only")
-        self.help = _("install newer images only")
+        self.label = _("Install the newer image only")
+        self.help = _("install the newer image only")
         
     def installedBuild(self):
         """
