@@ -1,6 +1,6 @@
 #-*- coding: utf-8 -*-
 
-# Copyright 2008-2012 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -56,11 +56,17 @@ class VariableOsInstallKernelScheduler(Variable):
                 if "OCZ" in dev_name or "SSD" in dev_name:
                     return "noop"
         else:
-            return getValueFromCmdLine('elevator',0) or "cfq"
+            currentScheduler = getValueFromCmdLine('elevator',0)
+            if currentScheduler in map(lambda x:x[0],self.choice()):
+                return currentScheduler
         return "cfq"
     
     def choice(self):
-        return [("deadline","Deadline"),("cfq","CFQ"),("noop","No-op")]
+        schedulers = [("deadline","Deadline"),("cfq","CFQ"),("noop","No-op")]
+        if self.Get('os_install_kernel_bfq_set') == 'on':
+            return schedulers + [("bfq","BFQ")]
+        else:
+            return schedulers
 
     def uncompatible(self):
         """
@@ -69,6 +75,23 @@ class VariableOsInstallKernelScheduler(Variable):
         if self.Get('os_install_root_type') == 'flash':
             return _("I/O scheduler unavailable for Flash install")
 
+class VariableOsInstallKernelBfqSet(ReadonlyVariable):
+    """
+    Available BFQ in kernel
+    """
+    type = "bool"
+
+    def get(self):
+        image = self.Get('cl_image')
+        if image:
+            with image as distr:
+                distrPath = image.getDirectory()
+                kernelConfig = path.join(distrPath,"usr/src/linux/.config")
+                if filter(lambda x:"CONFIG_IOSCHED_BFQ=y" in x,
+                    readLinesFile(kernelConfig)):
+                    return "on"
+        return "off"
+
 class VariableOsInstallKernelAttr(Variable):
     """
     Install kernel attributes
@@ -93,7 +116,11 @@ class VariableOsInstallKernelResume(ReadonlyVariable):
         for dev, install in zip(self.Get('os_install_disk_use'),
                                 self.Get('os_install_disk_mount')):
             if install == "swap":
-                return "real_resume=%s"%dev
+                if self.Get('os_install_linux_system') == 'desktop':
+                    return \
+                        "tuxonice tuxonice_resume=%s real_resume=%s"%(dev,dev)
+                else:
+                    return "real_resume=%s"%dev
         return ""
 
 class KernelHelper:
