@@ -1,6 +1,6 @@
 #-*- coding: utf-8 -*-
 
-# Copyright 2008-2012 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -26,7 +26,7 @@ setLocalTranslate('cl_install3',sys.modules[__name__])
 
 from calculate.lib.utils.ip import (getInterfaces,getIp,getMask,getMac,
     cidrToMask,maskToCidr,getIpNet,isDhcpIp,checkIp,checkMask,
-    getOperState)
+    getOperState,getPlugged)
 from calculate.lib.utils.device import lspci
 from calculate.lib.utils.files import listDirectory,readLinesFile,process,\
                                       readFile
@@ -261,6 +261,8 @@ class VariableOsInstallNetStatus(NetHelper,Variable):
 
     def getDefaultValue(self,iface):
         def statusValue(ipaddr,dhcp):
+            if not getPlugged(iface):
+                return 'off'
             if dhcp == "on":
                 return "dhcp"
             elif ipaddr:
@@ -289,7 +291,7 @@ class VariableOsInstallNetStatus(NetHelper,Variable):
 
     def choice(self):
         return (("dhcp",_("DHCP")),
-                ("off", _("disable")),
+                ("off", _("Disabled")),
                 ("auto", _("Auto")))
 
 class VariableOsInstallNetIp(NetHelper,ReadonlyVariable):
