@@ -1,6 +1,6 @@
 #-*- coding: utf-8 -*-
 
-# Copyright 2008-2012 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -173,6 +173,15 @@ class VariableClInstallHomeCryptSet(UserHelper,Variable):
         self.help = _("crypt user profiles")
         self.label = _("Crypt user profiles")
 
+    def get(self):
+        return ("off" if self.Get('cl_autologin')
+                else self.Get('cl_home_crypt_set'))
+
+    def check(self,value):
+        if value == "on" and self.Get('cl_autologin'):
+            raise VariableError(
+                _("Crypt user profile uncompatible with autologin"))
+
 class VariableClMigrateData(UserHelper,TableVariable):
     """
     User migrate data table
@@ -383,8 +392,6 @@ class VariableOsInstallDevFrom(Variable):
     """
     Root device of previous installed os
     """
-    value = ""
-
     def set(self,value):
         """
         If device in calculate3.env dev_from not exists set ''
@@ -396,6 +403,13 @@ class VariableOsInstallDevFrom(Variable):
         else:
             return ""
 
+    def get(self):
+        if (self.Get('cl_autopartition_set') == 'on' and 
+            "root" in self.Get('cl_autopartition_scheme')):
+            return self.Select('cl_autopartition_disk_dev',
+                    where='cl_autopartition_disk_scheme',eq='root',limit=1)
+        return ""
+
 class VariableClInstallAutoupdateSet(Variable):
     """
     Autoupdate for install or configure system
@@ -613,14 +627,16 @@ class VariableOsInstallUefiSet(Variable):
             if self.Get('os_uefi_set') == 'off' and \
                 self.Get('os_install_root_type') == 'hdd':
                 raise VariableError(
-                  _("System must be loaded in UEFI for using this bootloader"))
+                  _("Your system must be loaded in UEFI for using this "
+                    "bootloader"))
             if not 'gpt' in self.Get('os_device_table'):
                 raise VariableError(
-                    _("Need GPT for using UEFI bootloader"))
+                    _("GPT is needed for using the UEFI bootloader"))
             if not (self.Get('os_install_disk_efi') or \
                 "/boot/efi" in self.Get('os_location_dest')):
                 raise VariableError(
-                    _("Need EF00 partition for using UEFI bootloader"))
+                    _("A EF00 partition is needed for using "
+                      "the UEFI bootloader"))
             if self.Get('os_install_arch_machine') != 'x86_64':
                 raise VariableError(
                     _("Architecture of the target system must be x86_64"))
@@ -682,7 +698,7 @@ class VariableOsAudioData(ReadonlyTableVariable):
         aplay = getProgPath('/usr/bin/aplay')
         if not aplay:
             return [[]]
-        entry = re.compile('^card (\d+): ([^,]+)')
+        entry = re.compile('^card (\d+): ([^:]+)')
         return tuple(map(lambda x:x.groups(),
                filter(None,map(entry.search,
                process(aplay,'-l')))))
@@ -750,6 +766,6 @@ class VariableOsAudioDefault(Variable):
         """
         Audio setting up unavailable for flash installation
         """
-        if self.Get('os_install_root_type') == 'flash':
+        if self.Get('os_install_root_type') != 'flash':
             return _("Audio configuration unavailable for Flash install")
         return ""
